pub async fn same_content_from_files_async_with_buffer_size<const BUFFER_SIZE: usize>(
a: &mut File,
b: &mut File,
) -> Result<bool, Error>Available on crate feature
tokio only.Expand description
Determines whether two Tokio files have the same content using BUFFER_SIZE bytes per stream.
BUFFER_SIZE must be greater than zero, and both files are rewound to the beginning when their lengths match.