pub async fn same_content_from_readers_async_with_buffer_size<const BUFFER_SIZE: usize>(
a: &mut (dyn AsyncRead + Unpin),
b: &mut (dyn AsyncRead + Unpin),
) -> Result<bool, Error>Available on crate feature
tokio only.Expand description
Determines whether two Tokio readers have the same remaining content using BUFFER_SIZE bytes per stream.
BUFFER_SIZE must be greater than zero, and reading starts at each reader’s current position.